#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage		   : http://www.uvena.de/gigolo/
# source location  : http://files.uvena.de/gigolo/gigolo-0.4.0.tar.bz2
# dependency       : GLib,GVFS,intltool,gtk+
# last revised     : 8.1.2010

softname='gigolo'
softversion='0.4.1'
packageversion='66.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://files.uvena.de/gigolo/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
gigolo: gigolo - A network manager to remove filesystems
gigolo:
gigolo: gigolo is a frontend to easily manage connections to remote filesystems 
gigolo: using GIO/GVFS. It allows you to quickly connect/mount a remote 
gigolo: filesystem and manage bookmarks of such. 
gigolo:
gigolo:
gigolo:
gigolo:
gigolo: 
gigolo:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
./waf configure --prefix="/usr"
./waf build
./waf install --destdir=$dest

# .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Network shares
Comment=A simple frontend to easily connect to remote filesystems
Exec=gigolo
Icon=gtk-network
Categories=Application;Network;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README README.I18N TODO\
      $dest/usr/doc/$softname-$softversion
	
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
mkdir -p $dest/$prefix/man
mv $dest/usr/share/man $dest/$prefix
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,expat,fontconfig,freetype,\
gcc,glib2,gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,\
libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libpng,libxcb,pango,pixman,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/gigolo/source/build-gigolo.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
